@@ -83,7 +83,7 @@ if __name__ == '__main__':
     else:
         outerImg = os.getcwd() + '\\' + args.img1[0]
     if os.path.isabs(args.img2[0]):
-        innerImg = img.open(args.img2[0])
+        innerImg = args.img2[0]
     else:
         innerImg = os.getcwd() + '\\' + args.img2[0]
 
